@@ -17,3 +17,5 @@
 # pylint: disable=wildcard-import
 from .core import *
 from .operations import *
+from .util import *
+from .zmq import *
